==> zio-aws-wafv2_2.13-5.17.128.1-sources.jar: zio/aws/wafv2/model/UpdateRuleGroupResponse.scala <==
package zio.aws.wafv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.wafv2.model.primitives.LockToken
import scala.jdk.CollectionConverters._
final case class UpdateRuleGroupResponse(
    nextLockToken: Option[LockToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.wafv2.model.UpdateRuleGroupResponse = {
    import UpdateRuleGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.wafv2.model.UpdateRuleGroupResponse
      .builder()
      .optionallyWith(
        nextLockToken.map(value => LockToken.unwrap(value): java.lang.String)
      )(_.nextLockToken)
      .build()
  }
  def asReadOnly: zio.aws.wafv2.model.UpdateRuleGroupResponse.ReadOnly =
    zio.aws.wafv2.model.UpdateRuleGroupResponse.wrap(buildAwsValue())
}
object UpdateRuleGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.wafv2.model.UpdateRuleGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafv2.model.UpdateRuleGroupResponse =
      zio.aws.wafv2.model
        .UpdateRuleGroupResponse(nextLockToken.map(value => value))
    def nextLockToken: Option[LockToken]
    def getNextLockToken: ZIO[Any, AwsError, LockToken] =
      AwsError.unwrapOptionField("nextLockToken", nextLockToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.wafv2.model.UpdateRuleGroupResponse
  ) extends zio.aws.wafv2.model.UpdateRuleGroupResponse.ReadOnly {
    override val nextLockToken: Option[LockToken] = scala
      .Option(impl.nextLockToken())
      .map(value => zio.aws.wafv2.model.primitives.LockToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.wafv2.model.UpdateRuleGroupResponse
  ): zio.aws.wafv2.model.UpdateRuleGroupResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-wafv2_2.13-6.20.42.2-sources.jar: zio/aws/wafv2/model/UpdateRuleGroupResponse.scala <==
package zio.aws.wafv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.wafv2.model.primitives.LockToken
import scala.jdk.CollectionConverters._
final case class UpdateRuleGroupResponse(
    nextLockToken: Optional[LockToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.wafv2.model.UpdateRuleGroupResponse = {
    import UpdateRuleGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.wafv2.model.UpdateRuleGroupResponse
      .builder()
      .optionallyWith(
        nextLockToken.map(value => LockToken.unwrap(value): java.lang.String)
      )(_.nextLockToken)
      .build()
  }
  def asReadOnly: zio.aws.wafv2.model.UpdateRuleGroupResponse.ReadOnly =
    zio.aws.wafv2.model.UpdateRuleGroupResponse.wrap(buildAwsValue())
}
object UpdateRuleGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.wafv2.model.UpdateRuleGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafv2.model.UpdateRuleGroupResponse =
      zio.aws.wafv2.model
        .UpdateRuleGroupResponse(nextLockToken.map(value => value))
    def nextLockToken: Optional[LockToken]
    def getNextLockToken: ZIO[Any, AwsError, LockToken] =
      AwsError.unwrapOptionField("nextLockToken", nextLockToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.wafv2.model.UpdateRuleGroupResponse
  ) extends zio.aws.wafv2.model.UpdateRuleGroupResponse.ReadOnly {
    override val nextLockToken: Optional[LockToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextLockToken())
      .map(value => zio.aws.wafv2.model.primitives.LockToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.wafv2.model.UpdateRuleGroupResponse
  ): zio.aws.wafv2.model.UpdateRuleGroupResponse.ReadOnly = new Wrapper(impl)
}
